@@ -1890,8 +1890,8 @@ extern "C" SkShader* C_SkShaders_Color2(const SkColor4f* color, SkColorSpace* co
     return SkShaders::Color(*color, sp(colorSpace)).release();
 }
 
-extern "C" SkShader* C_SkShaders_Blend(SkBlendMode mode, SkShader* dst, SkShader* src) {
-    return SkShaders::Blend(mode, sp(dst), sp(src)).release();
+extern "C" SkShader* C_SkShaders_Blend(SkBlender* blender, SkShader* dst, SkShader* src) {
+    return SkShaders::Blend(sp(blender), sp(dst), sp(src)).release();
 }
 
 extern "C" SkShader* C_SkShader_Deserialize(const void* data, size_t length) {
@@ -1899,7 +1899,7 @@ extern "C" SkShader* C_SkShader_Deserialize(const void* data, size_t length) {
     // https://github.com/rust-skia/rust-skia/issues/146
     // "typeinfo for SkShader", referenced from:
     //      _C_SkShader_Deserialize in libcanvasnative.a(bindings.o)
-    return (SkShader*)(SkShader::Deserialize(SkFlattenable::Type::kSkShaderBase_Type, data, length).release());
+    return (SkShader*)(SkShader::Deserialize(SkFlattenable::Type::kSkShader_Type, data, length).release());
 }
 
 //
@@ -2325,15 +2325,14 @@ SkImage *C_SkRuntimeEffect_makeImage(
     const SkRuntimeEffect *self,
     GrRecordingContext* context,
     SkData *uniforms,
-    SkShader **children, size_t childCount,
+    SkRuntimeEffect::ChildPtr *children, size_t childCount,
     const SkMatrix *localMatrix,
     const SkImageInfo *resultInfo,
     bool mipmapped) {
-    auto childrenSPs = reinterpret_cast<sk_sp<SkShader> *>(children);
     return self->makeImage(
         context,
         sp(uniforms),
-        childrenSPs, childCount,
+        SkSpan<SkRuntimeEffect::ChildPtr>(children, childCount),
         localMatrix, *resultInfo, mipmapped).release();
 }
 
@@ -2343,6 +2342,12 @@ SkColorFilter *C_SkRuntimeEffect_makeColorFilter(
     return self->makeColorFilter(sp(inputs), SkSpan<SkRuntimeEffect::ChildPtr>(children, childCount)).release();
 }
 
+SkBlender *C_SkRuntimeEffect_makeBlender(
+    const SkRuntimeEffect *self, SkData *uniforms, SkRuntimeEffect::ChildPtr *children, size_t childCount)
+{
+    return self->makeBlender(sp(uniforms), SkSpan<SkRuntimeEffect::ChildPtr>(children, childCount)).release();
+}
+
 const unsigned char* C_SkRuntimeEffect_source(const SkRuntimeEffect *self, size_t* len) {
     auto& str = self->source();
     *len = str.length();
@@ -2419,12 +2424,12 @@ SkImageFilter *C_SkImageFilters_Arithmetic(float k1, float k2, float k3, float k
                                       sp(foreground), *cropRect).release();
 }
 
-SkImageFilter *C_SkImageFilters_Blend(SkBlendMode mode,
+SkImageFilter *C_SkImageFilters_Blend(SkBlender *blender,
                                       SkImageFilter *background,
                                       SkImageFilter *foreground,
                                       const SkImageFilters::CropRect *cropRect)
 {
-    return SkImageFilters::Blend(mode, sp(background),
+    return SkImageFilters::Blend(sp(blender), sp(background),
                                  sp(foreground), *cropRect)
         .release();
 }
